@@ -4,7 +4,7 @@ use warnings;
 
 package Pod::Weaver::PluginBundle::MARCEL;
 BEGIN {
-  $Pod::Weaver::PluginBundle::MARCEL::VERSION = '1.100950';
+  $Pod::Weaver::PluginBundle::MARCEL::VERSION = '1.100980';
 }
 
 # ABSTRACT: build POD documentation like MARCEL
@@ -55,7 +55,7 @@ Pod::Weaver::PluginBundle::MARCEL - build POD documentation like MARCEL
 
 =head1 VERSION
 
-version 1.100950
+version 1.100980
 
 =head1 SYNOPSIS
 
@@ -122,11 +122,6 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Pod-Weaver-PluginBundle-MARCEL/>.
 
-The development version lives at
-L<http://github.com/hanekomu/Pod-Weaver-PluginBundle-MARCEL/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
-
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
